@@ -504,7 +504,6 @@ where
         }
     }
 
-    // TODO: rewrite https://www.w3.org/TR/css-syntax-3/#consume-an-ident-like-token
     fn read_ident_like(&mut self) -> LexResult<Token> {
         let name = self.read_name()?;
 
@@ -515,6 +514,7 @@ where
 
             self.skip_ws()?;
 
+            // TODO: avoid reset
             match self.input.cur() {
                 Some('"' | '\'') => {
                     self.input.reset_to(start_whitespace);
@@ -532,6 +532,16 @@ where
             }
         }
 
+        if self.input.is_byte(b'(') {
+            self.input.bump();
+            self.last_pos = Some(self.input.cur_pos());
+
+            return Ok(Token::Function {
+                value: name.0,
+                raw: name.1,
+            });
+        }
+
         Ok(Token::Ident {
             value: name.0,
             raw: name.1,
@@ -612,7 +622,10 @@ where
                 // EOF
                 // This is a parse error. Return the <string-token>.
                 None => {
-                    return Err(ErrorKind::Eof);
+                    return Ok(Token::Str {
+                        value: value.into(),
+                        raw: raw.into(),
+                    })
                 }
             }
         }
@@ -709,8 +722,10 @@ where
                             });
                         }
                         None => {
-                            // TODO: This is a parse error. Return the <url-token>.
-                            return Err(ErrorKind::Eof);
+                            return Ok(Token::Url {
+                                value: value.into(),
+                                raw: raw.into(),
+                            });
                         }
                         _ => {}
                     }
